[llvm-commits] CVS: llvm/include/llvm/CodeGen/MachineCodeForBasicBlock.h MachineCodeForMethod.h MachineFunction.h PhyRegAlloc.h

Misha Brukman brukman at neo.cs.uiuc.edu
Sun Oct 27 18:26:01 PST 2002


Changes in directory llvm/include/llvm/CodeGen:

MachineCodeForBasicBlock.h updated: 1.3 -> 1.4
MachineCodeForMethod.h updated: 1.8 -> 1.9
MachineFunction.h updated: 1.8 -> 1.9
PhyRegAlloc.h updated: 1.36 -> 1.37

---
Log message:

Changed `MachineCodeForMethod' to `MachineFunction'.


---
Diffs of the changes:

Index: llvm/include/llvm/CodeGen/PhyRegAlloc.h
diff -u llvm/include/llvm/CodeGen/PhyRegAlloc.h:1.36 llvm/include/llvm/CodeGen/PhyRegAlloc.h:1.37
--- llvm/include/llvm/CodeGen/PhyRegAlloc.h:1.36	Mon Jul  8 17:39:36 2002
+++ llvm/include/llvm/CodeGen/PhyRegAlloc.h	Sun Oct 27 18:25:36 2002
@@ -35,7 +35,7 @@
 #include <vector>
 #include <map>
 
-class MachineCodeForMethod;
+class MachineFunction;
 class MachineRegInfo;
 class FunctionLiveVarInfo;
 class MachineInstr;
@@ -71,7 +71,7 @@
   std::vector<RegClass *> RegClassList; // vector of register classes
   const TargetMachine &TM;              // target machine
   const Function *Meth;                 // name of the function we work on
-  MachineCodeForMethod &mcInfo;         // descriptor for method's native code
+  MachineFunction &mcInfo;              // descriptor for method's native code
   FunctionLiveVarInfo *const LVI;       // LV information for this method 
                                         // (already computed for BBs) 
   LiveRangeInfo LRI;                    // LR info  (will be computed)





More information about the llvm-commits mailing list
Index: llvm/include/llvm/CodeGen/MachineCodeForBasicBlock.h
diff -u llvm/include/llvm/CodeGen/MachineCodeForBasicBlock.h:1.3 llvm/include/llvm/CodeGen/MachineCodeForBasicBlock.h:1.4
--- llvm/include/llvm/CodeGen/MachineCodeForBasicBlock.h:1.3	Sun Oct 27 14:49:47 2002
+++ llvm/include/llvm/CodeGen/MachineCodeForBasicBlock.h	Sun Oct 27 18:25:36 2002
@@ -1,27 +1,31 @@
-//===-- llvm/CodeGen/MachineCodeForBasicBlock.h -----------------*- C++ -*--=//
+//===-- llvm/CodeGen/MachineBasicBlock.h ------------------------*- C++ -*--=//
 // 
 // Collect the sequence of machine instructions for a basic block.
 //
 //===---------------------------------------------------------------------===//
 
-#ifndef LLVM_CODEGEN_MACHINECODEFORBASICBLOCK_H
-#define LLVM_CODEGEN_MACHINECODEFORBASICBLOCK_H
+#ifndef LLVM_CODEGEN_MACHINEBASICBLOCK_H
+#define LLVM_CODEGEN_MACHINEBASICBLOCK_H
 
 #include "llvm/BasicBlock.h"
 class MachineInstr;
 
 extern AnnotationID MCFBB_AID;
 
-class MachineCodeForBasicBlock : public Annotation {
+// FIXME: this should go away soon
+class MachineBasicBlock;
+typedef MachineBasicBlock MachineCodeForBasicBlock;
+
+class MachineBasicBlock: public Annotation {
   std::vector<MachineInstr*> Insts;
 public:
-  MachineCodeForBasicBlock();
-  ~MachineCodeForBasicBlock() {}
+  MachineBasicBlock();
+  ~MachineBasicBlock() {}
   
   // Static methods to retrieve or destroy the MachineCodeForBasicBlock
   // object for a given basic block.
-  static MachineCodeForBasicBlock& get(const BasicBlock *bb) {
-    return *(MachineCodeForBasicBlock*)bb->getOrCreateAnnotation(MCFBB_AID);
+  static MachineBasicBlock& get(const BasicBlock *bb) {
+    return *(MachineBasicBlock*)bb->getOrCreateAnnotation(MCFBB_AID);
   }
   
   static void destroy(const BasicBlock *bb) {
@@ -1,27 +1,31 @@
   
-  // Static methods to retrieve or destroy the MachineCodeForBasicBlock
+  // Static methods to retrieve or destroy the MachineBasicBlock
   // object for a given basic block.


Index: llvm/include/llvm/CodeGen/MachineCodeForMethod.h
diff -u llvm/include/llvm/CodeGen/MachineCodeForMethod.h:1.8 llvm/include/llvm/CodeGen/MachineCodeForMethod.h:1.9
--- llvm/include/llvm/CodeGen/MachineCodeForMethod.h:1.8	Wed Jul 24 16:21:28 2002
+++ llvm/include/llvm/CodeGen/MachineCodeForMethod.h	Sun Oct 27 18:25:36 2002
@@ -1,4 +1,4 @@
-//===-- llvm/CodeGen/MachineCodeForMethod.h ----------------------*- C++ -*--=//
+//===-- llvm/CodeGen/MachineFunction.h ----------------------*- C++ -*--=//
 // 
 // Purpose:
 //   Collect native machine code information for a method.
@@ -6,8 +6,8 @@
 //   to be stored with each method.
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_CODEGEN_MACHINECODEFORMETHOD_H
-#define LLVM_CODEGEN_MACHINECODEFORMETHOD_H
+#ifndef LLVM_CODEGEN_MACHINEFUNCTION_H
+#define LLVM_CODEGEN_MACHINEFUNCTION_H
 
 #include "llvm/Annotation.h"
 #include "Support/NonCopyable.h"
@@ -19,8 +19,11 @@
 class Type;
 class TargetMachine;
 
+// FIXME: this should go away soon
+class MachineFunction;
+typedef MachineFunction MachineCodeForMethod;
 
-class MachineCodeForMethod : private Annotation {
+class MachineFunction : private Annotation {
   hash_set<const Constant*> constantsForConstPool;
   hash_map<const Value*, int> offsets;
   const         Function* method;
@@ -36,20 +39,20 @@
   bool          automaticVarsAreaFrozen;
   
 public:
-  /*ctor*/      MachineCodeForMethod(const Function* function,
+  /*ctor*/      MachineFunction(const Function* function,
                                      const TargetMachine& target);
   
   // The next two methods are used to construct and to retrieve
   // the MachineCodeForMethod object for the given method.
   // construct() -- Allocates and initializes for a given method and target
   // get()       -- Returns a handle to the object.
   //                This should not be called before "construct()"
   //                for a given Method.
   // 
-  static MachineCodeForMethod& construct(const Function *method,
+  static MachineFunction& construct(const Function *method,
                                          const TargetMachine &target);
   static void destruct(const Function *F);
-  static MachineCodeForMethod& get(const Function* function);
+  static MachineFunction& get(const Function* function);
   
   //
   // Accessors for global information about generated code for a method.
@@ -36,20 +39,20 @@
   
   // The next two methods are used to construct and to retrieve
-  // the MachineCodeForMethod object for the given method.
+  // the MachineFunction object for the given method.
   // construct() -- Allocates and initializes for a given method and target
   // get()       -- Returns a handle to the object.


Index: llvm/include/llvm/CodeGen/MachineFunction.h
diff -u llvm/include/llvm/CodeGen/MachineFunction.h:1.8 llvm/include/llvm/CodeGen/MachineFunction.h:1.9
--- llvm/include/llvm/CodeGen/MachineFunction.h:1.8	Wed Jul 24 16:21:28 2002
+++ llvm/include/llvm/CodeGen/MachineFunction.h	Sun Oct 27 18:25:36 2002
@@ -1,13 +1,13 @@
-//===-- llvm/CodeGen/MachineCodeForMethod.h ----------------------*- C++ -*--=//
+//===-- llvm/CodeGen/MachineFunction.h ---------------------------*- C++ -*--=//
 // 
-// Purpose:
-//   Collect native machine code information for a method.
-//   This allows target-specific information about the generated code
-//   to be stored with each method.
+// Collect native machine code information for a method.  This allows
+// target-specific information about the generated code to be stored with each
+// method.
+//   
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_CODEGEN_MACHINECODEFORMETHOD_H
-#define LLVM_CODEGEN_MACHINECODEFORMETHOD_H
+#ifndef LLVM_CODEGEN_MACHINEFUNCTION_H
+#define LLVM_CODEGEN_MACHINEFUNCTION_H
 
 #include "llvm/Annotation.h"
 #include "Support/NonCopyable.h"
@@ -20,7 +20,7 @@
 class TargetMachine;
 
 
-class MachineCodeForMethod : private Annotation {
+class MachineFunction : private Annotation {
   hash_set<const Constant*> constantsForConstPool;
   hash_map<const Value*, int> offsets;
   const         Function* method;
@@ -36,20 +36,20 @@
   bool          automaticVarsAreaFrozen;
   
 public:
-  /*ctor*/      MachineCodeForMethod(const Function* function,
-                                     const TargetMachine& target);
+  /*ctor*/      MachineFunction(const Function* function,
+                                const TargetMachine& target);
   
   // The next two methods are used to construct and to retrieve
   // the MachineCodeForMethod object for the given method.
   // construct() -- Allocates and initializes for a given method and target
   // get()       -- Returns a handle to the object.
   //                This should not be called before "construct()"
   //                for a given Method.
   // 
-  static MachineCodeForMethod& construct(const Function *method,
+  static MachineFunction& construct(const Function *method,
                                          const TargetMachine &target);
   static void destruct(const Function *F);
-  static MachineCodeForMethod& get(const Function* function);
+  static MachineFunction& get(const Function* function);
   
   //
   // Accessors for global information about generated code for a method.
@@ -36,20 +36,20 @@
   
   // The next two methods are used to construct and to retrieve
-  // the MachineCodeForMethod object for the given method.
+  // the MachineFunction object for the given method.
   // construct() -- Allocates and initializes for a given method and target
   // get()       -- Returns a handle to the object.

